@@ -91,6 +91,11 @@ class GitHook(BaseHook):
             return
         if self.auth_token and self.repo_url.startswith("https://"):
             self.repo_url = self.repo_url.replace("https://", f"https://{self.user_name}:{self.auth_token}@")
+        elif self.auth_token and self.repo_url.startswith("http://"):
+            self.repo_url = self.repo_url.replace("http://", f"http://{self.user_name}:{self.auth_token}@")
+        elif self.repo_url.startswith("http://"):
+            # if no auth token, use the repo url as is
+            self.repo_url = self.repo_url
         elif not self.repo_url.startswith("git@") or not self.repo_url.startswith("https://"):
             self.repo_url = os.path.expanduser(self.repo_url)
 
